==> duiba-goods-center-api-0.0.4-20220401.122218-40-sources.jar: cn/com/duiba/cloud/duiba/goods/center/api/dto/goods/SkuDto.java <==
package cn.com.duiba.cloud.duiba.goods.center.api.dto.goods;

import cn.com.duiba.cloud.duiba.goods.center.api.constant.GeneralTypeEnum;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.channel.ItemChannelDto;
import cn.com.duiba.cloud.duiba.goods.center.api.util.GoodsSnapshotUtil;
import com.alibaba.fastjson.annotation.JSONField;
import lombok.Getter;
import lombok.Setter;

/**
 * @author zsp (zengshuiping@duiba.com.cn)
 * @date 2021/11/8 1:47 下午
 */
@Getter
@Setter
public class SkuDto extends AbstractGoodsDto {
    private static final long serialVersionUID = 1L;
    /**
     * 商品id
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private Long spuId;
    /**
     * sku编码
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private String skuCode;

    /**
     * 渠道库存相关
     *
     * @deprecated 不再需要
     */
    @Deprecated
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private ItemChannelDto itemChannel;

    /**
     * spuID或skuID
     */
    @Override
    public Long getGeneralId() {
        return getId();
    }

    /**
     * 类型(1:spu;2:sku)
     *
     * @see GeneralTypeEnum
     */
    @Override
    public Integer getGeneralType() {
        return GeneralTypeEnum.SKU.getGeneralType();
    }


    /**
     * 是否删除(0:未删除,1:已删除)
     */
    private Integer isDeleted;


    /**
     * 该sku的属性值拼接
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private String attributeValue;


    /**
     * 是否是新建sku
     * 不落库
     */
    private Boolean newSku;
}

==> duiba-goods-center-api-0.0.5-20220518.094822-7-sources.jar: cn/com/duiba/cloud/duiba/goods/center/api/dto/goods/SkuDto.java <==
package cn.com.duiba.cloud.duiba.goods.center.api.dto.goods;

import cn.com.duiba.cloud.duiba.goods.center.api.constant.GeneralTypeEnum;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.channel.ItemChannelDto;
import cn.com.duiba.cloud.duiba.goods.center.api.dto.coupon.CouponDTO;
import cn.com.duiba.cloud.duiba.goods.center.api.util.GoodsSnapshotUtil;
import com.alibaba.fastjson.annotation.JSONField;
import lombok.Getter;
import lombok.Setter;

/**
 * @author zsp (zengshuiping@duiba.com.cn)
 * @date 2021/11/8 1:47 下午
 */
@Getter
@Setter
public class SkuDto extends AbstractGoodsDto {
    private static final long serialVersionUID = 1L;
    /**
     * 商品id
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private Long spuId;
    /**
     * sku编码
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private String skuCode;

    /**
     * 渠道库存相关
     *
     * @deprecated 不再需要
     */
    @Deprecated
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private ItemChannelDto itemChannel;

    /**
     * 关联的卡券批次
     */
    private CouponDTO couponDTO;

   
    /**
     * spuID或skuID
     */
    @Override
    public Long getGeneralId() {
        return getId();
    }

    /**
     * 类型(1:spu;2:sku)
     *
     * @see GeneralTypeEnum
     */
    @Override
    public Integer getGeneralType() {
        return GeneralTypeEnum.SKU.getGeneralType();
    }


    /**
     * 是否删除(0:未删除,1:已删除)
     */
    private Integer isDeleted;


    /**
     * 该sku的属性值拼接
     */
    @JSONField(label = GoodsSnapshotUtil.LABEL_SUPPLIER)
    private String attributeValue;


    /**
     * 是否是新建sku
     * 不落库
     */
    private Boolean newSku;


    /**
     * 库存预警
     */
    private StockWarnConfigDto stockWarnConfigDto;
}
